@@ -210,9 +210,9 @@ fn make() -> clap::Command {
         .arg(
             Arg::new("message-id")
                 .long("message-id")
-                .help("Create Message-Id trailer from Message-ID header")
+                .help("Create Message-ID trailer from Message-ID header")
                 .long_help(
-                    "Create Message-Id trailer in patch description based on the \
+                    "Create Message-ID trailer in patch description based on the \
                     Message-ID email header. This option is applicable when importing \
                     with '--mail' or '--mbox'. This behavior may also be enabled via \
                     the \"stgit.import.message-id\" configuration option.",
@@ -500,7 +500,7 @@ fn import_file<'repo>(
         if message.len() > 1 && &message[message.len() - 2..] != b"\n\n" {
             message.push(b'\n');
         }
-        message.push_str("Message-Id: ");
+        message.push_str("Message-ID: ");
         message.push_str(message_id);
         message.push(b'\n');
     }
@@ -581,7 +581,7 @@ fn create_patch<'repo>(
         patchname
     };
 
-    let author_date = author_date.and_then(|date| gix::actor::Time::parse_time(&date).ok());
+    let author_date = author_date.and_then(|date| gix::date::Time::parse_time(&date).ok());
     let author = if let (Some(name), Some(email), Some(time)) =
         (author_name.as_deref(), author_email.as_deref(), author_date)
     {
@@ -913,6 +913,7 @@ impl Headers {
 
             if headers.subject.is_some() {
                 split_message.push_str(line.strip_prefix(dedent.as_bytes()).unwrap_or(line));
+                split_message.push_char('\n');
                 break;
             }
 
