@@ -28,8 +28,8 @@ test_expect_success 'Test behavior on empty repo' '
 
 test_expect_success 'Create ten patches' '
     for i in 0 1 2 3 4 5 6 7 8 9; do
-        stg new p$i -m p$i;
-        git notes add -m note$i;
+        stg new p$i -m p$i &&
+        git notes add -m note$i || return 1
     done &&
     [ "$(echo $(stg series --applied --noprefix))" = "p0 p1 p2 p3 p4 p5 p6 p7 p8 p9" ] &&
     [ "$(echo $(stg series --unapplied --noprefix))" = "" ]
@@ -120,7 +120,7 @@ test_expect_success 'Push all but three patches' '
 '
 
 test_expect_success 'Push two patches in reverse' '
-    stg push -n 2 --reverse
+    stg push -n 2 --reverse &&
     [ "$(echo $(stg series --applied --noprefix))" = "p0 p1 p2 p3 p4 p5 p6 p8 p7" ] &&
     [ "$(echo $(stg series --unapplied --noprefix))" = "p9" ] &&
     [ "$(git notes show)" = "note7" ]
